==> eam-wshub-proxyclient-11.6-2-sources.jar: net/datastream/schemas/mp_functions/mp7274_001/MP7274_SyncStandardWOChild_001.java <==

package net.datastream.schemas.mp_functions.mp7274_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.standardwochild_001.StandardWOChild;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/StandardWOChild_001}StandardWOChild"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OLDSEQUENCE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OLDSTEP"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Sync" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="StandardWOChild" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "standardWOChild",
    "oldsequence",
    "oldstep"
})
@XmlRootElement(name = "MP7274_SyncStandardWOChild_001")
public class MP7274_SyncStandardWOChild_001 {

    @XmlElement(name = "StandardWOChild", namespace = "http://schemas.datastream.net/MP_entities/StandardWOChild_001", required = true)
    protected StandardWOChild standardWOChild;
    @XmlElement(name = "OLDSEQUENCE", namespace = "http://schemas.datastream.net/MP_fields")
    protected long oldsequence;
    @XmlElement(name = "OLDSTEP", namespace = "http://schemas.datastream.net/MP_fields")
    protected long oldstep;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Obtient la valeur de la propriété standardWOChild.
     * 
     * @return
     *     possible object is
     *     {@link StandardWOChild }
     *     
     */
    public StandardWOChild getStandardWOChild() {
        return standardWOChild;
    }

    /**
     * Définit la valeur de la propriété standardWOChild.
     * 
     * @param value
     *     allowed object is
     *     {@link StandardWOChild }
     *     
     */
    public void setStandardWOChild(StandardWOChild value) {
        this.standardWOChild = value;
    }

    /**
     * Obtient la valeur de la propriété oldsequence.
     * 
     */
    public long getOLDSEQUENCE() {
        return oldsequence;
    }

    /**
     * Définit la valeur de la propriété oldsequence.
     * 
     */
    public void setOLDSEQUENCE(long value) {
        this.oldsequence = value;
    }

    /**
     * Obtient la valeur de la propriété oldstep.
     * 
     */
    public long getOLDSTEP() {
        return oldstep;
    }

    /**
     * Définit la valeur de la propriété oldstep.
     * 
     */
    public void setOLDSTEP(long value) {
        this.oldstep = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.SYNC;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.STANDARD_WO_CHILD;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_functions/mp7274_001/MP7274_SyncStandardWOChild_001.java <==

package net.datastream.schemas.mp_functions.mp7274_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.standardwochild_001.StandardWOChild;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/StandardWOChild_001}StandardWOChild"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OLDSEQUENCE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OLDSTEP"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Sync" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="StandardWOChild" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "standardWOChild",
    "oldsequence",
    "oldstep"
})
@XmlRootElement(name = "MP7274_SyncStandardWOChild_001")
public class MP7274_SyncStandardWOChild_001 {

    @XmlElement(name = "StandardWOChild", namespace = "http://schemas.datastream.net/MP_entities/StandardWOChild_001", required = true)
    protected StandardWOChild standardWOChild;
    @XmlElement(name = "OLDSEQUENCE", namespace = "http://schemas.datastream.net/MP_fields")
    protected long oldsequence;
    @XmlElement(name = "OLDSTEP", namespace = "http://schemas.datastream.net/MP_fields")
    protected long oldstep;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Gets the value of the standardWOChild property.
     * 
     * @return
     *     possible object is
     *     {@link StandardWOChild }
     *     
     */
    public StandardWOChild getStandardWOChild() {
        return standardWOChild;
    }

    /**
     * Sets the value of the standardWOChild property.
     * 
     * @param value
     *     allowed object is
     *     {@link StandardWOChild }
     *     
     */
    public void setStandardWOChild(StandardWOChild value) {
        this.standardWOChild = value;
    }

    /**
     * Gets the value of the oldsequence property.
     * 
     */
    public long getOLDSEQUENCE() {
        return oldsequence;
    }

    /**
     * Sets the value of the oldsequence property.
     * 
     */
    public void setOLDSEQUENCE(long value) {
        this.oldsequence = value;
    }

    /**
     * Gets the value of the oldstep property.
     * 
     */
    public long getOLDSTEP() {
        return oldstep;
    }

    /**
     * Sets the value of the oldstep property.
     * 
     */
    public void setOLDSTEP(long value) {
        this.oldstep = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.SYNC;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.STANDARD_WO_CHILD;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}
